# Copyright 1999-2017. Parallels IP Holdings GmbH. All Rights Reserved.

import stat
import logging as log


class FileStat:
    REG = 'file'
    DIR = 'directory'
    LNK = 'symlink'
    SCK = 'socket'
    CHR = 'chardevice'

    def __init__(self, perms=None, user=None, group=None, typ=None, link_to=None):
        self.perms = perms
        self.user = user
        self.group = group
        self.typ = typ
        self.link_to = link_to

    def __str__(self):
        s = "%s %s:%s %s" % (self.perms, self.user, self.group, self.typ)
        if self.typ == FileStat.LNK:
            s += " -> " + self.link_to
        return s

    def __eq__(self, other):
        return all([
            self.perms == other.perms,
            self.user == other.user,
            self.group == other.group,
            self.typ == other.typ,
            self.link_to == other.link_to,
        ])

    def set_mode(self, mode):
        self.perms = oct(mode & 0777)
        if stat.S_ISLNK(mode):
            self.typ = FileStat.LNK
        elif stat.S_ISREG(mode):
            self.typ = FileStat.REG
        elif stat.S_ISDIR(mode):
            self.typ = FileStat.DIR
        elif stat.S_ISSOCK(mode):
            self.typ = FileStat.SCK
        elif stat.S_ISCHR(mode):
            self.typ = FileStat.CHR
        else:
            self.typ = None
            log.warning("Unknown file mode: %s" % oct(mode))
